@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20190320';
+our $VERSION = '5.20190419';
 our %utilities;
 
 sub utilities {
@@ -1480,6 +1480,13 @@ my %delta = (
         removed => {
         }
     },
+    5.028002 => {
+        delta_from => 5.028001,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
